dir <- "/Users/David/Grive/Slater_Lab/Charadriiformes/Burleigh_et_al_data/"

aln_file <- read.table(paste(dir, "AllCharadriiformes.phy", sep = ""), stringsAsFactors = F)
gene_borders <- read.table(paste(dir, "GeneBorders.txt", sep = ""), stringsAsFactors = F)

for(i in 1:nrow(gene_borders)) {
  gene_name <- ifelse(length(strsplit(gene_borders[i,1], "\\.")[[1]]) > 1,
                      strsplit(gene_borders[i,1], "\\.")[[1]][1],
                      strsplit(gene_borders[i,1], "_")[[1]][1])
  
  gene <- substr(aln_file[,2], gene_borders[i,2], gene_borders[i,3])
  
  # Remove all sequences consisting exclusively of gaps:
  to_remove <- vector()
  for(j in 1:length(gene)) {
    sites <- strsplit(gene[j], "")[[1]]
    if (all(sites == "-")) {
      to_remove <- c(to_remove, j)
    }
  }
  
  # Skip the gene if it is not sampled for any of the charadriiform species:
  if(length(to_remove) == length(gene)) {
    print(paste("Skipping gene", gene_name))
    next
  }
  
  sampled_spp <- aln_file[,1][-to_remove]
  seqs <- gene[-to_remove]
  # Remove higher-taxon prefixes from sequence labels
  names <- sapply(sampled_spp, function(x) paste(strsplit(x, "_")[[1]][c(3,4)], collapse = "_"))
  names(names) <- NULL
  
  # Sort alphabetically
  indices <- sort.int(names, index.return = T)$ix
  names <- names[indices]
  seqs <- seqs[indices]
  # Remove synonyms, (?) subspecies
  duplicates <- which(duplicated(names))
  
  if (length(duplicates) != 0) {
    aln <- cbind(names[-duplicates], seqs[-duplicates])
  } else {
    aln <- cbind(names, seqs)
  }

  write(names, paste(dir, "species_sampled/", gene_name, ".txt", sep = ""))
  write.table(aln, paste(dir, "gene_alignments/", gene_name, ".phy", sep = ""), quote = F,
              col.names = F, row.names = F, sep = "\n")
}